==> haskell-quickcheck-safe-0.1.0.6-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-safe.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 QuickCheck-safe
version:              0.1.0.6
visibility:           public
id:                   QuickCheck-safe-0.1.0.6-Kw7xBu8V39JC1pAnu8rfG3
key:                  QuickCheck-safe-0.1.0.6-Kw7xBu8V39JC1pAnu8rfG3
license:              MIT
copyright:            2015,2017 Bertram Felgenhauer
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:               Bertram Felgenhauer
synopsis:             Safe reimplementation of QuickCheck'\''s core
description:
    QuickCheck-safe reimplements the quickCheck functionality with a pure
    interface and a very small trusted base (see Test.QuickCheck.Safe.Trusted).

    * uses the existing Arbitrary instances
    * implemented features: testing, result minimization (i.e., shrinking)
    * missing features: expected failures, label frequencies, coverage

    The package is targeted at users who want to leverage SafeHaskell for
    sandboxing.

    >>> putStr $ quickCheck (inventQCGen ()) (\x -> length (x :: [()]) < 10)
    *** Failed! Falsifiable (after 18 tests and 3 shrinks):
    [(),(),(),(),(),(),(),(),(),(),(),(),(),(),()]

category:             Testing
abi:                  80b0ec9efa350fc32dcacb937fefa295
exposed:              True
exposed-modules:      Test.QuickCheck.Safe Test.QuickCheck.Safe.Trusted
import-dirs:          /usr/lib/ghc-9.4.8/site-local/QuickCheck-safe-0.1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/QuickCheck-safe-0.1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/QuickCheck-safe-0.1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-safe
hs-libraries:         HSQuickCheck-safe-0.1.0.6-Kw7xBu8V39JC1pAnu8rfG3
depends:
    QuickCheck-2.14.3-ErwepKtibZRAZpHWEytr6k base-4.17.2.1
    containers-0.6.7

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-safe/html/QuickCheck-safe.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-safe/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-safe-0.1.0.6-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-safe.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 QuickCheck-safe
version:              0.1.0.6
visibility:           public
id:                   QuickCheck-safe-0.1.0.6-HSlDWDloDRC9vNL6ojnovU
key:                  QuickCheck-safe-0.1.0.6-HSlDWDloDRC9vNL6ojnovU
license:              MIT
copyright:            2015,2017 Bertram Felgenhauer
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:               Bertram Felgenhauer
synopsis:             Safe reimplementation of QuickCheck'\''s core
description:
    QuickCheck-safe reimplements the quickCheck functionality with a pure
    interface and a very small trusted base (see Test.QuickCheck.Safe.Trusted).

    * uses the existing Arbitrary instances
    * implemented features: testing, result minimization (i.e., shrinking)
    * missing features: expected failures, label frequencies, coverage

    The package is targeted at users who want to leverage SafeHaskell for
    sandboxing.

    >>> putStr $ quickCheck (inventQCGen ()) (\x -> length (x :: [()]) < 10)
    *** Failed! Falsifiable (after 18 tests and 3 shrinks):
    [(),(),(),(),(),(),(),(),(),(),(),(),(),(),()]

category:             Testing
abi:                  5009763ee774abc94da3354d0bb2839f
exposed:              True
exposed-modules:      Test.QuickCheck.Safe Test.QuickCheck.Safe.Trusted
import-dirs:          /usr/lib/ghc-9.4.8/site-local/QuickCheck-safe-0.1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/QuickCheck-safe-0.1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/QuickCheck-safe-0.1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-safe
hs-libraries:         HSQuickCheck-safe-0.1.0.6-HSlDWDloDRC9vNL6ojnovU
depends:
    QuickCheck-2.14.3-1OQe8vVNhDx8BJsM0dw2LX base-4.17.2.1
    containers-0.6.7

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-safe/html/QuickCheck-safe.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-safe/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
